package com.jeeplus.human.enrollment.enrollmentRegistration.service;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.extra.spring.SpringUtil;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jeeplus.common.TokenProvider;
import com.jeeplus.human.enrollment.enrollmentRegistration.domain.EnrollmentFamilyInfo;
import com.jeeplus.human.enrollment.enrollmentRegistration.domain.EnrollmentLanguageInfo;
import com.jeeplus.human.enrollment.enrollmentRegistration.mapper.EnrollmentFamilyInfoMapper;
import com.jeeplus.human.enrollment.enrollmentRegistration.mapper.EnrollmentLanguageInfoMapper;
import com.jeeplus.sys.domain.WorkAttachmentInfo;
import com.jeeplus.sys.feign.IUserApi;
import com.jeeplus.sys.feign.IWorkAttachmentApi;
import com.jeeplus.sys.service.dto.UserDTO;
import com.jeeplus.sys.service.dto.WorkAttachmentInfoDTO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * @version 1.0
 * @date 2023-10-17 8:57
 */
@Service
@Transactional
public class EnrollmentFamilyInfoService extends ServiceImpl<EnrollmentFamilyInfoMapper, EnrollmentFamilyInfo> {

    @Resource
    private EnrollmentFamilyInfoMapper mapper;

    public void deleteByRegistrationId(String id){
        QueryWrapper<EnrollmentFamilyInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("enrollment_registration_id",id);
        mapper.delete(queryWrapper);
    }

    public EnrollmentFamilyInfo findById(String id) throws Exception {
        // 查询基础信息表
        EnrollmentFamilyInfo info = mapper.getById(id);
        return info;
    }

    /**
     * 根据关联id查询所有数据
     * @param id
     * @return
     */
    public List<EnrollmentFamilyInfo> findByRegistrationId(String id)  {
        QueryWrapper<EnrollmentFamilyInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("enrollment_registration_id",id);
        List<EnrollmentFamilyInfo> infos = mapper.selectList(queryWrapper);
        return infos;
    }

    public void saveOrUpdateInfo(EnrollmentFamilyInfo info) {
        if (info == null) {
            return ;
        }
        if (!StringUtils.isNotBlank(info.getId())) {
            // 新增
            add(info);
        } else {
            // 更新
            update(info);
        }
    }

    /**
     * 新增
     * @param info
     */
    public void add(EnrollmentFamilyInfo info){
        mapper.insert(info);
    }

    public void update(EnrollmentFamilyInfo info){
        UserDTO userDTO = SpringUtil.getBean(IUserApi.class).getByToken(TokenProvider.getCurrentToken());
        mapper.updateById(info);
    }

}
